@@ -6,16 +6,17 @@ import os
 import sys
 from argparse import Namespace
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Sequence, Union
 
 import yaml
 
+from ansiblelint.config import DEFAULT_KINDS
 from ansiblelint.constants import (
     CUSTOM_RULESDIR_ENVVAR,
     DEFAULT_RULESDIR,
     INVALID_CONFIG_RC,
 )
-from ansiblelint.file_utils import expand_path_vars
+from ansiblelint.file_utils import expand_path_vars, guess_project_dir, normpath
 
 _logger = logging.getLogger(__name__)
 _PATH_VARS = [
@@ -29,10 +30,8 @@ def abspath(path: str, base_dir: str) -> str:
 
     Args:
        path (str): the path to make absolute
-       base_dir (str): the directory from which make relative paths
-           absolute
-       default_drive: Windows drive to use to make the path
-           absolute if none is given.
+       base_dir (str): the directory from which make \
+                       relative paths absolute
     """
     if not os.path.isabs(path):
         # Don't use abspath as it assumes path is relative to cwd.
@@ -42,7 +41,10 @@ def abspath(path: str, base_dir: str) -> str:
     return os.path.normpath(path)
 
 
-def expand_to_normalized_paths(config: dict, base_dir: str = None) -> None:
+def expand_to_normalized_paths(
+    config: Dict[str, Any], base_dir: Optional[str] = None
+) -> None:
+    """Mutate given config normalizing any path values in it."""
     # config can be None (-c /dev/null)
     if not config:
         return
@@ -82,6 +84,8 @@ def load_config(config_file: str) -> Dict[Any, Any]:
     except yaml.YAMLError as e:
         _logger.error(e)
         sys.exit(INVALID_CONFIG_RC)
+
+    config['config_file'] = config_path
     # TODO(ssbarnea): implement schema validation for config file
     if isinstance(config, list):
         _logger.error(
@@ -92,6 +96,7 @@ def load_config(config_file: str) -> Dict[Any, Any]:
 
     config_dir = os.path.dirname(config_path)
     expand_to_normalized_paths(config, config_dir)
+
     return config
 
 
@@ -104,20 +109,35 @@ def get_config_path(config_file: str = '.ansible-lint') -> Optional[str]:
             filename = os.path.abspath(os.path.join(parent, project_filename))
             if os.path.exists(filename):
                 return filename
+            if os.path.exists(os.path.abspath(os.path.join(parent, '.git'))):
+                # Avoid looking outside .git folders as we do not want endup
+                # picking config files from upper level projects if current
+                # project has no config.
+                return None
         (parent, tail) = os.path.split(parent)
     return None
 
 
 class AbspathArgAction(argparse.Action):
-    def __call__(self, parser, namespace, values, option_string=None):
+    def __call__(
+        self,
+        parser: argparse.ArgumentParser,
+        namespace: Namespace,
+        values: Union[str, Sequence[Any], None],
+        option_string: Optional[str] = None,
+    ) -> None:
         if isinstance(values, (str, Path)):
             values = [values]
-        normalized_values = [Path(expand_path_vars(path)).resolve() for path in values]
-        previous_values = getattr(namespace, self.dest, [])
-        setattr(namespace, self.dest, previous_values + normalized_values)
+        if values:
+            normalized_values = [
+                Path(expand_path_vars(str(path))).resolve() for path in values
+            ]
+            previous_values = getattr(namespace, self.dest, [])
+            setattr(namespace, self.dest, previous_values + normalized_values)
 
 
 def get_cli_parser() -> argparse.ArgumentParser:
+    """Initialize an argument parser."""
     parser = argparse.ArgumentParser()
 
     parser.add_argument(
@@ -131,22 +151,22 @@ def get_cli_parser() -> argparse.ArgumentParser:
         '-f',
         dest='format',
         default='rich',
-        choices=['rich', 'plain', 'rst', 'codeclimate'],
+        choices=['rich', 'plain', 'rst', 'codeclimate', 'quiet', 'pep8'],
         help="Format used rules output, (default: %(default)s)",
     )
     parser.add_argument(
         '-q',
         dest='quiet',
-        default=False,
-        action='store_true',
-        help="quieter, although not silent output",
+        default=0,
+        action='count',
+        help="quieter, reduce verbosity, can be specified twice.",
     )
     parser.add_argument(
         '-p',
         dest='parseable',
         default=False,
         action='store_true',
-        help="parseable output in the format of pep8",
+        help="parseable output, same as '-f pep8'",
     )
     parser.add_argument(
         '--parseable-severity',
@@ -164,6 +184,13 @@ def get_cli_parser() -> argparse.ArgumentParser:
         " of violations compared with previous git commit. This "
         "feature works only in git repositories.",
     )
+    parser.add_argument(
+        '--project-dir',
+        dest='project_dir',
+        default=".",
+        help="Location of project/repository, autodetected based on location "
+        " of configuration file.",
+    )
     parser.add_argument(
         '-r',
         action=AbspathArgAction,
@@ -201,7 +228,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         '-v',
         dest='verbosity',
         action='count',
-        help="Increase verbosity level",
+        help="Increase verbosity level (-vv for more)",
         default=0,
     )
     parser.add_argument(
@@ -219,6 +246,13 @@ def get_cli_parser() -> argparse.ArgumentParser:
         help="only warn about these rules, unless overridden in "
         "config file defaults to 'experimental'",
     )
+    parser.add_argument(
+        '--enable-list',
+        dest='enable_list',
+        default=[],
+        action='append',
+        help="activate optional rules by their tag name",
+    )
     # Do not use store_true/store_false because they create opposite defaults.
     parser.add_argument(
         '--nocolor',
@@ -268,7 +302,8 @@ def get_cli_parser() -> argparse.ArgumentParser:
     return parser
 
 
-def merge_config(file_config, cli_config: Namespace) -> Namespace:
+def merge_config(file_config: Dict[Any, Any], cli_config: Namespace) -> Namespace:
+    """Combine the file config with the CLI args."""
     bools = (
         'display_relative_path',
         'parseable',
@@ -280,16 +315,20 @@ def merge_config(file_config, cli_config: Namespace) -> Namespace:
     )
     # maps lists to their default config values
     lists_map = {
-        'exclude_paths': [],
+        'exclude_paths': [".cache", ".git", ".hg", ".svn", ".tox"],
         'rulesdir': [],
         'skip_list': [],
         'tags': [],
-        'warn_list': ['experimental'],
+        'warn_list': ['experimental', 'role-name'],
         'mock_modules': [],
         'mock_roles': [],
+        'enable_list': [],
     }
 
-    scalar_map = {"loop_var_prefix": None}
+    scalar_map = {
+        "loop_var_prefix": None,
+        "project_dir": ".",
+    }
 
     if not file_config:
         # use defaults if we don't have a config file and the commandline
@@ -324,10 +363,16 @@ def merge_config(file_config, cli_config: Namespace) -> Namespace:
     for entry, value in file_config.items():
         setattr(cli_config, entry, value)
 
+    # append default kinds to the custom list
+    kinds = file_config.get('kinds', [])
+    kinds.extend(DEFAULT_KINDS)
+    setattr(cli_config, 'kinds', kinds)
+
     return cli_config
 
 
 def get_config(arguments: List[str]) -> Namespace:
+    """Extract the config based on given args."""
     parser = get_cli_parser()
     options = parser.parse_args(arguments)
 
@@ -337,10 +382,21 @@ def get_config(arguments: List[str]) -> Namespace:
 
     options.rulesdirs = get_rules_dirs(options.rulesdir, options.use_default_rules)
 
+    if options.project_dir == ".":
+        project_dir = guess_project_dir(options.config_file)
+        options.project_dir = normpath(project_dir)
+    if not options.project_dir or not os.path.exists(options.project_dir):
+        raise RuntimeError(
+            f"Failed to determine a valid project_dir: {options.project_dir}"
+        )
+
+    # Compute final verbosity level by subtracting -q counter.
+    options.verbosity -= options.quiet
     return config
 
 
-def print_help(file=sys.stdout):
+def print_help(file: Any = sys.stdout) -> None:
+    """Print help test to the given stream."""
     get_cli_parser().print_help(file=file)
 
 
